@@ -37,12 +37,6 @@ bool _af_filehandle_ok (AFfilehandle file);
 
 bool _af_filehandle_can_read (AFfilehandle file);
 
-void _af_printid (u_int32_t id);
-void _af_print_filehandle (AFfilehandle filehandle);
-void _af_print_tracks (AFfilehandle filehandle);
-void _af_print_channel_matrix (double *matrix, int fchans, int vchans);
-void _af_print_pvlist (AUpvlist list);
-
 void *_af_malloc (size_t size);
 void *_af_realloc (void *ptr, size_t size);
 void *_af_calloc (size_t nmemb, size_t size);
@@ -52,6 +46,10 @@ AUpvlist _af_pv_long (long val);
 AUpvlist _af_pv_double (double val);
 AUpvlist _af_pv_pointer (void *val);
 
+bool _af_pv_getlong (AUpvlist pvlist, int param, long *l);
+bool _af_pv_getdouble (AUpvlist pvlist, int param, double *d);
+bool _af_pv_getptr (AUpvlist pvlist, int param, void **v);
+
 _TrackSetup *_af_filesetup_get_tracksetup (AFfilesetup setup, int trackid);
 _Track *_af_filehandle_get_track (AFfilehandle file, int trackid);
 
@@ -67,10 +65,14 @@ status _af_set_sample_format (_AudioFormat *f, int sampleFormat, int sampleWidth
 bool _af_filehandle_can_read (AFfilehandle file);
 bool _af_filehandle_can_write (AFfilehandle file);
 
-void _af_print_audioformat (_AudioFormat *format);
-void _af_print_chunk (_AFchunk *chunk);
-void _af_print_frame (AFframecount frameno, double *frame, int nchannels,
-	char *formatstring, int numberwidth,
-	double slope, double intercept, double minclip, double maxclip);
+status af_read_uint32_be (u_int32_t *value, AFvirtualfile *vf);
+status af_read_uint32_le (u_int32_t *value, AFvirtualfile *vf);
+status af_read_uint16_be (u_int16_t *value, AFvirtualfile *vf);
+status af_read_uint16_le (u_int16_t *value, AFvirtualfile *vf);
+
+status af_write_uint32_be (const u_int32_t *value, AFvirtualfile *vf);
+status af_write_uint32_le (const u_int32_t *value, AFvirtualfile *vf);
+status af_write_uint16_be (const u_int16_t *value, AFvirtualfile *vf);
+status af_write_uint16_le (const u_int16_t *value, AFvirtualfile *vf);
 
 #endif
