@@ -18,19 +18,26 @@
 	Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 	MA 02111-1307, USA.
 */
+
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
-
-#include <sys/types.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
+#include <sys/types.h>
 
 #ifdef __USE_SGI_HEADERS__
 #include <dmedia/audiofile.h>
 #else
-#include "audiofile.h"
+#include <audiofile.h>
+#endif
+
+#ifdef DEBUG
+#define DEBG printf
+#else
+#define DEBG
 #endif
 
 char copyright[] = "1998 Michael Pruett";
@@ -39,32 +46,55 @@ char name[] = "Michael Pruett's home-brew methamphetamines";
 /* Two frames of 16-bit stereo samples. */
 u_int16_t data[] = {0, 1, 2, 3};
 
-int main (int argc, char *argv[])
+int main (int argc, char **argv)
 {
+	int		filefmt;
 	AFfilehandle	file;
-	AFfilesetup		setup;
-	int				miscids[] = {1, 2};
-	int				result;
+	AFfilesetup	setup;
+	int		miscids[] = {1, 2};
+	int		result;
 
-	if (argc < 2)
+	if (argc < 3)
 	{
-		fprintf(stderr, "usage: %s <audio file>\n", argv[0]);
-		exit(0);
+		fprintf(stderr, "usage: %s <file format> <audio file>\n",
+			argv[0]);
+		exit(EXIT_FAILURE);
+	}
+
+	if (strcmp(argv[1], "aiff") == 0)
+		filefmt = AF_FILE_AIFF;
+	else if (strcmp(argv[1], "aifc") == 0)
+		filefmt = AF_FILE_AIFFC;
+	else if (strcmp(argv[1], "wave") == 0)
+		filefmt = AF_FILE_WAVE;
+	else
+	{
+		fprintf(stderr, "unrecognized file format '%s'\n", argv[1]);
+		exit(EXIT_FAILURE);
 	}
 
 	setup = afNewFileSetup();
+	afInitFileFormat(setup, filefmt);
 	afInitMiscIDs(setup, miscids, 2);
 	afInitMiscType(setup, 1, AF_MISC_COPY);
 	afInitMiscType(setup, 2, AF_MISC_NAME);
 	afInitMiscSize(setup, 1, strlen(copyright));
 	afInitMiscSize(setup, 2, strlen(name));
 
-	file = afOpenFile(argv[1], "w", setup);
+	file = afOpenFile(argv[2], "w", setup);
+	if (file == NULL)
+	{
+		fprintf(stderr, "could not open file '%s' for writing\n", argv[2]);
+		exit(EXIT_FAILURE);
+	}
 
 	result = afWriteMisc(file, 1, copyright, strlen(copyright));
-	printf("result = %d\n", result);
+	DEBG("wrote miscellaneous data of type %d with length = %d\n",
+		afGetMiscType(file, 1), result);
 	result = afWriteMisc(file, 2, name, strlen(name));
-	printf("result = %d\n", result);
+
+	DEBG("wrote miscellaneous data of type %d with length = %d\n",
+		afGetMiscType(file, 2), result);
 
 	/* Write out two token frames of sample data. */
 	afWriteFrames(file, AF_DEFAULT_TRACK, data, 2);
